
Package: google-android-platform-$X-installer
Architecture: all
Depends: ${googleAndroidInstallers:Depends},
         ${misc:Depends}
Description: Google's Android SDK Platform $X Installer
 This package will download the Google's Android SDK Platform $X package and
 unpacks it into Debian-friendly paths.
 .
 Google's Android SDK Platform includes android.jar file with fully compliant
 Android library. In order to build an Android app, this SDK platform must be
 specified as build target.
 .
 WARNING: Installing this Debian package causes $Y
 to be downloaded from dl.google.com and/or from other suggested mirrors. The
 End User License Agreement of this binary package is available at
 developer.android.com.
