Template: google-android-installers/mirror
Type: select
Choices: https://dl.google.com, http://mirrors.neusoft.edu.cn, http://android-mirror.bugly.qq.com:8080
Default: https://dl.google.com
_Description: Mirror to download packages ?
 Please select your prefered mirror to download Google's Android packages from.
