#!/bin/sh

set -e

# Source debconf library.
. /usr/share/debconf/confmodule

#Get owners list
db_metaget google-android-installers/mirror owners
OWNERS=$RET

#Check if the package is the only owner
if [ "$OWNERS" = "google-android-platform-$X-installer" ]; then
	#Ask the quastion
	db_input high google-android-installers/mirror || true
	db_go
fi

#DEBHELPER#

exit 0
